package cn.iocoder.yudao.module.jx.service;

import cn.iocoder.yudao.module.jx.domain.DriveSchoolText;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import java.util.List;

/**
 * 驾校公告Service接口
 *
 * @author jzy
 * @date 2024-04-16
 */
public interface IDriveSchoolTextService
{
    /**
     * 查询驾校公告
     *
     * @param id 驾校公告主键
     * @return 驾校公告
     */
    public DriveSchoolText selectDriveSchoolTextById(Long id);

    /**
     * 查询驾校公告列表
     *
     * @param driveSchoolText 驾校公告
     * @return 驾校公告集合
     */
    public IPage<DriveSchoolText> selectDriveSchoolTextList(DriveSchoolText driveSchoolText, Page<DriveSchoolText> page);

    /**
     * 新增驾校公告
     *
     * @param driveSchoolText 驾校公告
     * @return 结果
     */
    public int insertDriveSchoolText(DriveSchoolText driveSchoolText);

    /**
     * 修改驾校公告
     *
     * @param driveSchoolText 驾校公告
     * @return 结果
     */
    public int updateDriveSchoolText(DriveSchoolText driveSchoolText);

    /**
     * 批量删除驾校公告
     *
     * @param ids 需要删除的驾校公告主键集合
     * @return 结果
     */
    public int deleteDriveSchoolTextByIds(Long[] ids);

    /**
     * 删除驾校公告信息
     *
     * @param id 驾校公告主键
     * @return 结果
     */
    public int deleteDriveSchoolTextById(Long id);
}
